@@ -38,6 +38,8 @@ def _formatImgUrl(raw, domain):
 		raw = re.sub('width=\d\d*', 'width=1300', raw)
 	if matchKey(raw, ['condecdn']):
 		raw = re.sub('/\d\d*/', '/1300/', raw)
+	if matchKey(raw, ['twreport']) and matchKey(raw, ['-tiny']):
+		raw = raw.replace('-tiny', '-desktop')
 	if raw.startswith('//'):
 		return 'https:' + raw
 	if raw.startswith('/'):
@@ -59,7 +61,7 @@ def _getImgInsideFigure(figure, domain):
 
 def _cleanupFigure(figure, domain):
 	iframe = figure.find('iframe')
-	if iframe:
+	if iframe and iframe.get('src'):
 		r = fact().new_tag("iframe", src = _formatImgUrl(iframe['src'], domain))
 		iframe.replace_with(r)
 		return figure
