@@ -16,10 +16,10 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("article"),
 		lambda x: x.find("article"),
 		lambda x: x.find("main"),
+		lambda x: x.find("div", {"id" : "article_cont"}),
 		lambda x: x.find("div", {"id" : "js_content"}),
 		lambda x: x.find("div", {"id" : "bodyContent"}),
 		lambda x: x.find("div", {"id" : "content_JS"}),
-		# lambda x: x.find("div", {"id" : "article-body"}),
 		lambda x: x.find("div", class_ = "main-post"),
 		lambda x: x.find("div", class_ = "article"),
 		lambda x: x.find("div", class_ = "field-name-body"),
@@ -37,6 +37,7 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "post-text"),
 		lambda x: x.find("div", class_ = "post-body"),
 		lambda x: x.find("div", class_ = "mainContent"),
+		lambda x: x.find("div", class_ = "pane-node-body"),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -49,11 +50,17 @@ def _getInnerArticle_(soup, domain):
 		'thepaper': [
 			lambda x: x.find("div", class_ = "news_txt"),
 			lambda x: x.find('div', class_ = 'news_part')],
+		'greenpeace.org': [
+			lambda x: x.find("section", class_ = 'ct-container'),
+			lambda x: x.find("div", class_ = 'descriptiveParagraph')],
 		'gravitysworm': [lambda x: x.find("div", class_ = "copy")],
 		'opinion.cw.com.tw': [lambda x: x.find("article"),],
 		'chinaworker.': [lambda x: x.find("div", class_ = 'pf-content'),],
 		'thesocietypages.org': [lambda x: x.find("div", class_ = 'post-content'),],
 		'chinadigitaltimes.': [lambda x: x.find("div", class_ = 'post-content'),],
+		'twreporter.org':[lambda x: x.find("div", {"id" : "article-body"}),],
+		'bbc.co.uk': [lambda x: x.find("div", {"dir": "ltr"})],
+		'bbc.com': [lambda x: x.find("article"), lambda x: x.find("main")],
 	}
 	is_short = matchKey(soup.text, SHORT_ARTICLE)
 	text_limit = 150 if is_short else 500
