@@ -29,7 +29,9 @@ OFFTOPIC_ATT = [
 	'socialBTN', 'page-view', 'pn-single-post-wrapper__social', 'pn-pagicle-widget',
 	'mashsb-container', 'give-form-wrap', 'story_bady_info_author',
 	'taglist', 'donate', 'see-also', 'donation-box', 'license__Container',
-	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list'
+	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list',
+	'tools__ShareIconBlock', 'aside__Container', 'MetadataAndTool', 'DesktopAsideBlock',
+	'StyledSeparationCurve'
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
@@ -62,7 +64,7 @@ def _isOffTopic(attrs):
 		return 
 	r = []
 	for k, v in attrs.items():
-		if matchKey(k, ['href', 'src', 'url', 'alt', 'data', 'xmlns:fb']):
+		if k != 'data-component' and matchKey(k, ['href', 'src', 'url', 'alt', 'data', 'xmlns:fb']):
 			continue
 		r.append(str(k) + ' : ' + str(v))
 	r = '\n'.join(r)
